==> mariadb-12.0.0.tar.gz: mariadb-12.0.0/cmake/submodule_info.cmake <==
SET(extra/wolfssl/wolfssl_TAG v5.7.6-stable)
SET(extra/wolfssl/wolfssl_REVISION 239b85c80)
SET(extra/wolfssl/wolfssl_URL https://github.com/wolfSSL/wolfssl)
SET(libmariadb_TAG v3.4.4)
SET(libmariadb_REVISION 93e42062)
SET(libmariadb_URL https://github.com/MariaDB/mariadb-connector-c)
SET(libmariadb/docs_TAG no-tag)
SET(libmariadb/docs_REVISION 7e12bce)
SET(libmariadb/docs_URL https://github.com/mariadb-corporation/mariadb-connector-c.wiki.git)
SET(storage/columnstore/columnstore_TAG no-tag)
SET(storage/columnstore/columnstore_REVISION 9763b1265)
SET(storage/columnstore/columnstore_URL https://github.com/mariadb-corporation/mariadb-columnstore-engine.git)
SET(storage/columnstore/columnstore/utils/libmarias3/libmarias3_TAG no-tag)
SET(storage/columnstore/columnstore/utils/libmarias3/libmarias3_REVISION f74150b)
SET(storage/columnstore/columnstore/utils/libmarias3/libmarias3_URL https://github.com/mariadb-corporation/libmarias3.git)
SET(storage/maria/libmarias3_TAG no-tag)
SET(storage/maria/libmarias3_REVISION 0d5babb)
SET(storage/maria/libmarias3_URL https://github.com/mariadb-corporation/libmarias3)
SET(storage/rocksdb/rocksdb_TAG no-tag)
SET(storage/rocksdb/rocksdb_REVISION bba5e7bc2)
SET(storage/rocksdb/rocksdb_URL https://github.com/facebook/rocksdb.git)
SET(wsrep-lib_TAG no-tag)
SET(wsrep-lib_REVISION 70cd967)
SET(wsrep-lib_URL https://github.com/codership/wsrep-lib.git)
SET(wsrep-lib/wsrep-API/v26_TAG no-tag)
SET(wsrep-lib/wsrep-API/v26_REVISION 12c02f5)
SET(wsrep-lib/wsrep-API/v26_URL https://github.com/codership/wsrep-API.git)
SET(ALL_SUBMODULES "extra/wolfssl/wolfssl;libmariadb;libmariadb/docs;storage/columnstore/columnstore;storage/columnstore/columnstore/utils/libmarias3/libmarias3;storage/maria/libmarias3;storage/rocksdb/rocksdb;wsrep-lib;wsrep-lib/wsrep-API/v26")
SET(GIT_REMOTE_ORIGIN_URL "https://github.com/mariadb/server.git")
SET(GIT_REV_SHORT "bd36f266f0f")

==> mariadb-12.0.2.tar.gz: mariadb-12.0.2/cmake/submodule_info.cmake <==
SET(extra/wolfssl/wolfssl_TAG no-tag)
SET(extra/wolfssl/wolfssl_REVISION b077c81eb)
SET(extra/wolfssl/wolfssl_URL https://github.com/wolfSSL/wolfssl)
SET(libmariadb_TAG no-tag)
SET(libmariadb_REVISION b790c6c1)
SET(libmariadb_URL https://github.com/MariaDB/mariadb-connector-c)
SET(libmariadb/docs_TAG no-tag)
SET(libmariadb/docs_REVISION 7e12bce)
SET(libmariadb/docs_URL https://github.com/mariadb-corporation/mariadb-connector-c.wiki.git)
SET(storage/columnstore/columnstore_TAG no-tag)
SET(storage/columnstore/columnstore_REVISION f33e9ce86)
SET(storage/columnstore/columnstore_URL https://github.com/mariadb-corporation/mariadb-columnstore-engine.git)
SET(storage/columnstore/columnstore/utils/libmarias3/libmarias3_TAG no-tag)
SET(storage/columnstore/columnstore/utils/libmarias3/libmarias3_REVISION d9cb536)
SET(storage/columnstore/columnstore/utils/libmarias3/libmarias3_URL https://github.com/mariadb-corporation/libmarias3.git)
SET(storage/maria/libmarias3_TAG no-tag)
SET(storage/maria/libmarias3_REVISION 0d5babb)
SET(storage/maria/libmarias3_URL https://github.com/mariadb-corporation/libmarias3)
SET(storage/rocksdb/rocksdb_TAG no-tag)
SET(storage/rocksdb/rocksdb_REVISION 79f08d7ff)
SET(storage/rocksdb/rocksdb_URL https://github.com/facebook/rocksdb.git)
SET(wsrep-lib_TAG no-tag)
SET(wsrep-lib_REVISION e55f01c)
SET(wsrep-lib_URL https://github.com/codership/wsrep-lib.git)
SET(wsrep-lib/wsrep-API/v26_TAG no-tag)
SET(wsrep-lib/wsrep-API/v26_REVISION 65608d3)
SET(wsrep-lib/wsrep-API/v26_URL https://github.com/codership/wsrep-API.git)
SET(ALL_SUBMODULES "extra/wolfssl/wolfssl;libmariadb;libmariadb/docs;storage/columnstore/columnstore;storage/columnstore/columnstore/utils/libmarias3/libmarias3;storage/maria/libmarias3;storage/rocksdb/rocksdb;wsrep-lib;wsrep-lib/wsrep-API/v26")
SET(GIT_REMOTE_ORIGIN_URL "https://github.com/mariadb/server.git")
SET(GIT_REV_SHORT "56abcc4087b")
